@@ -1,5 +1,8 @@
+__all__ = ['CurrencyRGame', 'Factory', 'GuessGame', 'mainGame',
+           'MemoryGame', 'utils', 'wog_abs']
+
 #from .__main__ import main
-import mainGame
+#import mainGame
 #from setuptools import setup, find_packages
 
 #setup(
